summaryrefslogtreecommitdiffstats
path: root/Source/cmCacheManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmCacheManager.h')
-rw-r--r--Source/cmCacheManager.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/Source/cmCacheManager.h b/Source/cmCacheManager.h
index 01bf98b..dd313bd 100644
--- a/Source/cmCacheManager.h
+++ b/Source/cmCacheManager.h
@@ -50,10 +50,14 @@ public:
//! Load a cache for given makefile. Loads from ouput home.
- bool LoadCache(cmMakefile*);
+ bool LoadCache(cmMakefile*);
+ //! Load a cache for given makefile. Loads from path/CMakeCache.txt.
+ bool LoadCache(const char* path);
- //! Save cache for given makefile. Saves to ouput home CMakeCache.txt
+ //! Save cache for given makefile. Saves to ouput home CMakeCache.txt.
bool SaveCache(cmMakefile*) const;
+ //! Save cache for given makefile. Saves to ouput path/CMakeCache.txt
+ bool SaveCache(const char* path) const;
//! Add an entry into the cache
void AddCacheEntry(const char* key, const char* value, CacheEntryType type);